@@ -16,8 +16,9 @@
 #include <string.h>
 #include <stdio.h>
 
-#define COMMAND_IR_ON  "ifconfig irda0 up ; echo 1 > /proc/sys/net/irda/discovery"
+#define COMMAND_IR_ON  "/sbin/ifconfig irda0 up ; echo 1 > /proc/sys/net/irda/discovery"
 #define COMMAND_IR_OFF  "echo 0 > /proc/sys/net/irda/discovery ; ifconfig irda0 down"
+#define COMMAND_ATTACH PREFIX "/sbin/irattach pxa_ir"
 
 void usage()
 {
@@ -36,6 +37,7 @@ main(int argc, char *argv[])
 	seteuid(0);
 	if (!strcmp(argv[1],"on"))
 	{
+		system(COMMAND_ATTACH);
 		system(COMMAND_IR_ON);
 		exit(0);
 	}
